@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::FibMXDeclare;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::FibMXDeclare::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # Fibonacci numbers
 
@@ -49,11 +52,34 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::FibMXDeclare
 
 =head1 NAME
 
 Benchmark::Perl::Formance::Plugin::FibMXDeclare - Stress recursion and method calls (MooseX::Declare)
 
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
