@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Incubator;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Incubator::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 use strict;
 use warnings;
@@ -61,7 +64,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Incubator
 
 =head1 NAME
 
@@ -72,5 +83,20 @@ Benchmark::Perl::Formance::Plugin::Incubator - Incubator plugin for benchmark ex
 This is a B<free style> plugin where I collect ideas. Although it
 might contain interesting code you should never rely on this plugin.
 
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
 
+
+__END__
+
+
