@@ -28,7 +28,8 @@ sub prepare {
         my ($options) = @_;
 
         my $dstdir = tempdir( CLEANUP => 1 );
-        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/RegexpCommonTS";
+        my $srcdir; eval { $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/RegexpCommonTS" };
+        return if $@;
 
         print STDERR "# Prepare cargo RegexpCommon testsuite in $dstdir ...\n" if $options->{verbose} >= 3;
 
@@ -48,11 +49,16 @@ sub prepare {
 sub nonaggregated {
         my ($dstdir, $prove, $recurse, $options) = @_;
 
-        my $cmd = "cd $dstdir ; $^X $prove $recurse '$dstdir/t'";
-        print STDERR "# $cmd\n"   if $options->{verbose} >= 3;
+        my $cmd = "cd $dstdir ; $^X $prove $recurse '$dstdir/t' 2>&1";
+        print STDERR "# $cmd\n"   if $options->{verbose} >= 4;
         print STDERR "# Run...\n" if $options->{verbose} >= 3;
 
-        my $t = timeit $count, sub { qx($cmd) };
+        my @output;
+        my $t = timeit $count, sub { @output = map { chomp; $_ } qx($cmd) };
+
+        my $maxerr = ($#output < 10) ? $#output : 10;
+        print STDERR join("\n# ", "", @output[0..$maxerr])    if $options->{verbose} >= 4;
+
         return {
                 Benchmark  => $t,
                 prove_path => $prove,
@@ -67,6 +73,8 @@ sub main {
         $recurse = $options->{fastmode} ? "" : "-r";
 
         my ($dstdir, $prove, $recurse) = prepare($options);
+        return { failed => "no Benchmark-Perl-Formance-Cargo" } if not $dstdir;
+
         return nonaggregated($dstdir, $prove, $recurse, $options);
 }
 
