@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::fannkuch;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Shootout::fannkuch::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # COMMAND LINE:
 # /usr/bin/perl fannkuch.perl-3.perl 12
@@ -108,7 +111,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Shootout::fannkuch
 
 =head1 NAME
 
@@ -118,3 +129,20 @@ Benchmark::Perl::Formance::Plugin::Shootout::fannkuch - Language shootout plugin
 
 This plugin does some runs the "fannkuch" benchmark from the Language
 Shootout.
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
