@@ -45,7 +45,9 @@ sub run
         $output = '';
         $threads = 2*num_cpus() || 1;
 
-        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/Shootout";
+        my $srcdir; eval { $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/Shootout" };
+        return { failed => "no Benchmark-Perl-Formance-Cargo" } if $@;
+
         my $srcfile = "$srcdir/$infile";
         open my $INFILE, "<", $srcfile or die "Cannot read $srcfile";
 
@@ -117,6 +119,8 @@ sub main
 
         my $result;
         my $t = timeit $count, sub { $result = run($goal) };
+        return $result if $result->{failed};
+
         return {
                 Benchmark => $t,
                 goal      => $goal,
