@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # COMMAND LINE:
 # /usr/bin/perl mandelbrot.perl 16000
@@ -117,7 +120,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot
 
 =head1 NAME
 
@@ -127,3 +138,20 @@ Benchmark::Perl::Formance::Plugin::Shootout::mandelbrot - Language shootout plug
 
 This plugin does some runs the "mandelbrot" benchmark from the
 Language Shootout.
+
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+
+__END__
+
