@@ -33,7 +33,9 @@ sub run
 {
         my ($infile) = @_;
 
-        my $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/Shootout";
+        my $srcdir; eval { $srcdir = dist_dir('Benchmark-Perl-Formance-Cargo')."/Shootout" };
+        return { failed => "no Benchmark-Perl-Formance-Cargo" } if $@;
+
         my $srcfile = "$srcdir/$infile";
         open my $INFILE, "<", $srcfile or die "Cannot read $srcfile";
 
@@ -104,6 +106,8 @@ sub main
 
         my $result;
         my $t = timeit $count, sub { $result = run($goal) };
+        return $result if $result->{failed};
+
         return {
                 Benchmark     => $t,
                 goal          => $goal,
