@@ -1,4 +1,7 @@
 package Benchmark::Perl::Formance::Plugin::Threads;
+BEGIN {
+  $Benchmark::Perl::Formance::Plugin::Threads::AUTHORITY = 'cpan:SCHWIGON';
+}
 
 # Create threads to evaluate Fibonacci numbers
 
@@ -77,11 +80,15 @@ sub main
 
 1;
 
-__END__
+
+
+=pod
+
+=encoding utf-8
 
 =head1 NAME
 
-Benchmark::Perl::Formance::Plugin::Threads - Stress threading
+Benchmark::Perl::Formance::Plugin::Threads
 
 =head1 SYNOPSIS
 
@@ -90,8 +97,27 @@ maximally be started. Default is 100.
 
   $ perl-formance --plugins=Threads -DThreads_threadcount=64
 
+=head1 NAME
+
+Benchmark::Perl::Formance::Plugin::Threads - Stress threading
+
 =head1 BUGS
 
 Too naive. Really.
 
+=head1 AUTHOR
+
+Steffen Schwigon <ss5@renormalist.net>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2012 by Steffen Schwigon.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
+
+
+__END__
+
